Package: SUITOR
Title: Selecting the number of mutational signatures through
        cross-validation
Version: 1.14.0
Date: 2022-05-10
Authors@R: c(person(given="DongHyuk", family="Lee", role="aut", email="dhyuklee@pusan.ac.kr"),
             person(given="Bin", family="Zhu", role="aut", email="bin.zhu@nih.gov"),
             person(given="Bill", family="Wheeler", role="cre", email="wheelerb@imsweb.com"))
Description: An unsupervised cross-validation method to select the optimal number of mutational signatures. A data set of mutational counts is split into training and validation data.Signatures are estimated in the training data and then used to predict the mutations in the validation data.
Imports: stats, utils, graphics, ggplot2, BiocParallel
Depends: R (>= 4.2.0)
License: GPL-2
biocViews: Genetics, Software, SomaticMutation
Suggests: devtools, MutationalPatterns, RUnit, BiocManager,
        BiocGenerics, BiocStyle, knitr, rmarkdown
NeedsCompilation: yes
BugReports: https://github.com/wheelerb/SUITOR/issues
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/SUITOR
git_branch: RELEASE_3_23
git_last_commit: ff103fd
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-29 01:03:11 UTC; biocbuild
Author: DongHyuk Lee [aut],
  Bin Zhu [aut],
  Bill Wheeler [cre]
Maintainer: Bill Wheeler <wheelerb@imsweb.com>
